==> php81-nextcloud-28.0.6.tgz: share/nextcloud/apps/theming/l10n/hu.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "A megadott név túl hosszú",
    "The given web address is too long" : "A megadott webcím túl hosszú",
    "The given web address is not a valid URL" : "A megadott webcím URL címe érvénytelen",
    "The given legal notice address is too long" : "A megadott jogi nyilatkozat címe túl hosszú",
    "The given legal notice address is not a valid URL" : "A megadott jogi nyilatkozat URL címe érvénytelen",
    "The given privacy policy address is too long" : "A megadott adatvédelmi irányelvek címe túl hosszú",
    "The given privacy policy address is not a valid URL" : "A megadott adatvédelmi irányelvek URL címe érvénytelen",
    "The given slogan is too long" : "A megadott szlogen túl hosszú",
    "The given color is invalid" : "A megadott szín érvénytelen",
    "Disable-user-theming should be true or false" : "A felhasználói témázás letiltásának igaznak vagy hamisnak kell lennie",
    "Saved" : "Mentve",
    "Invalid app given" : "Érvénytelen alkalmazás",
    "Invalid type for setting \"defaultApp\" given" : "A megadott „defaultApp” beállítás típusa érvénytelen",
    "Invalid setting key" : "Érvénytelen konfigurációs kulcs",
    "The file was uploaded" : "A fájl fel lett töltve",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "A feltöltött fájl meghaladja a php.ini upload_max_filesize direktívájában meghatározott méretet.",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "A feltöltött fájl meghaladja a HTML űrlapon megadott MAX_FILE_SIZE direktívájában meghatározott méretet.",
    "The file was only partially uploaded" : "A fájl csak részlegesen lett feltöltve",
    "No file was uploaded" : "Nincs feltöltött fájl",
    "Missing a temporary folder" : "Átmeneti mappa hiányzik",
    "Could not write file to disk" : "A fájlt nem sikerült a lemezre írni",
    "A PHP extension stopped the file upload" : "Egy PHP kiterjesztés megállította a fájl feltöltését",
    "No file uploaded" : "Nincs fájl feltöltve",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Már egyéni témát használ. Lehet, hogy a témázó alkalmazás beállításai felülírták.",
    "Theming" : "Témázás",
    "Appearance and accessibility" : "Megjelenés és akadálymentesítés",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Az „imagick” PHP-modul nem engedélyezett, de a témázó alkalmazás igen. A webhelyikonok előállításához telepítenie és engedélyeznie kell ezt a modult.",
    "Dark theme with high contrast mode" : "Sötét téma magas kontrasztú móddal",
    "Enable dark high contrast mode" : "Sötét, magas kontrasztú mód engedélyezése",
    "Similar to the high contrast mode, but with dark colours." : "Hasonló a magas kontrasztú módhoz, de sötét színekkel.",
    "Dark theme" : "Sötét téma",
    "Enable dark theme" : "Sötét téma engedélyezése",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Egy szemkímélő sötét téma, amely csökkenti az átlagos fényességet és fényerőt.",
    "System default theme" : "Rendszer alapértelmezett témája",
    "Enable the system default" : "Rendszer alapértelmezésének engedélyezése",
    "Using the default system appearance." : "Az alapértelmezett rendszermegjelenés használata.",
    "Dyslexia font" : "Diszlexia betűkészlet",
    "Enable dyslexia font" : "Diszlexia betűkészlet engedélyezése",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "Az OpenDyslexic egy szabad betűkészlet, amely egyes, diszlexia által okozott, gyakori olvasási hibák csökkentésére lett tervezve.",
    "High contrast mode" : "Magas kontrasztú mód",
    "Enable high contrast mode" : "Magas kontrasztú mód engedélyezése",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "A magas kontrasztú téma megkönnyíti a navigációt. A képi minőség csökken, de az olvashatóság javul.",
    "Light theme" : "Világos téma",
    "Enable the default light theme" : "Alapértelmezett világos téma engedélyezése",
    "The default light appearance." : "Az alapértelmezett világos megjelenés.",
    "Legal notice" : "Jogi nyilatkozat",
    "Privacy policy" : "Adatvédelmi irányelvek",
    "Adjust the Nextcloud theme" : "A Nextcloud téma módosítása",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "A témák lehetővé teszik, hogy könnyedén személyre szabja a példány és a támogatott kliensek megjelenését. Ez minden felhasználó számára látható lesz.",
    "Advanced options" : "Speciális beállítások",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Telepítse az ImageMagick PHP kiterjesztést SVG képtámogatással, hogy automatikusan előállítsa a kedvencek ikont a feltöltött logó és szín alapján.",
    "Name" : "Név",
    "Web link" : "Webes hivatkozás",
    "a safe home for all your data" : "biztonságos hely az adatai számára",
    "Slogan" : "Szlogen",
    "Color" : "Szín",
    "Logo" : "Logó",
    "Upload new logo" : "Új logó feltöltése",
    "Background and login image" : "Háttér és bejelentkezőkép",
    "Upload new background and login image" : "Új háttér és bejelentkezőkép feltöltése",
    "Legal notice link" : "Jogi nyilatkozat hivatkozása",
    "Privacy policy link" : "Adatvédelmi irányelvek hivatkozása",
    "Header logo" : "Fejléc logó",
    "Upload new header logo" : "Fejléc logó feltöltése",
    "Favicon" : "Kedvencek ikon",
    "Upload new favicon" : "Kedvencek ikon feltöltése",
    "User settings" : "Felhasználói beállítások",
    "Disable user theming" : "Felhasználói témázás letiltása",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Bár kiválaszthatja és testreszabhatja a példányát, a felhasználók módosíthatják a hátterüket és a színeiket. Ha ki akarja kényszeríteni a saját testreszabását, akkor bekapcsolja ezt. ",
    "Customization has been disabled by your administrator" : "A testreszabást letiltotta a rendszergazda",
    "Keyboard shortcuts" : "Gyorsbillentyűk",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Egyes esetekben a gyorsbillentyűk összeakadhatnak az akadálymentesítési eszközökkel. Hogy helyesen tudjon fókuszálni az eszközre, itt letilthatja a gyorsbillentyűket. Ez az alkalmazásokban is letiltja az összes elérhető gyorsbillentyűt.",
    "Disable all keyboard shortcuts" : "Összes gyorsbillentyű letiltása",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Az akadálymentesítés fontos számunka. A webes szabványokat követjük, és ellenőrizzük, hogy minden használható egér nélkül, illetve akadálymentesítési technológiákkal, például képernyőolvasókkal. Arra törekszünk, hogy a {guidelines}Webes tartalomra vonatkozó akadálymentesítési irányelvek{linkend} 2.1-es változatának AA szinten, a magas kontrasztú témával pedig AAA szinten megfeleljünk.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Ha problémákat tapasztal, jelentse a {issuetracker}hibakövetőnkben{linkend}. És ha segíteni szeretne, csatlakozzon a {designteam}dizájn csapatunkhoz{linkend}!",
    "Move up" : "Mozgatás fel",
    "Move down" : "Mozgatás le",
    "Custom background" : "Egyéni háttér",
    "Default background" : "Alapértelmezett háttér",
    "Change color" : "Szín módosítása",
    "No background" : "Nincs háttér",
    "Select a background from your files" : "Válasszon hátteret a fájljai közül",
    "Select background" : "Háttér választása",
    "No background has been selected" : "Nincs kiválasztott háttér",
    "Theme selection is enforced" : "A témaválasztás kényszerített",
    "Navigation bar settings" : "Navigációs sáv beállítás",
    "Could not set the app order" : "Nem sikerült az alkalmazások sorrendjének beállítása",
    "Default app" : "Alapértelmezett alkalmazás",
    "Use custom default app" : "Egyéni alapértelmezett alkalmazás",
    "Global default app" : "Globális alapértelmezett alkalmazás",
    "Global default apps" : "Globális alapértelmezett alkalmazások",
    "Default app priority" : "Alapértelmezett alkalmazás prioritás",
    "Could not set global default apps" : "Nem sikerült a globális alapértelmezett alkalmazások beállítása",
    "Reset to default" : "Visszaállítás alapértelmezettre",
    "Upload" : "Feltöltés",
    "Remove background image" : "Háttérkép eltávolítása",
    "Background" : "Háttér",
    "Set a custom background" : "Egyéni háttér beállítása",
    "Select a custom color" : "Válasszon egyéni színt"
},
"nplurals=2; plural=(n != 1);");

==> php81-nextcloud-30.0.5.tgz: share/nextcloud/apps/theming/l10n/hu.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "A megadott név túl hosszú",
    "The given web address is too long" : "A megadott webcím túl hosszú",
    "The given web address is not a valid URL" : "A megadott webcím URL címe érvénytelen",
    "The given legal notice address is too long" : "A megadott jogi nyilatkozat címe túl hosszú",
    "The given legal notice address is not a valid URL" : "A megadott jogi nyilatkozat URL címe érvénytelen",
    "The given privacy policy address is too long" : "A megadott adatvédelmi irányelvek címe túl hosszú",
    "The given privacy policy address is not a valid URL" : "A megadott adatvédelmi irányelvek URL címe érvénytelen",
    "The given slogan is too long" : "A megadott szlogen túl hosszú",
    "The given color is invalid" : "A megadott szín érvénytelen",
    "Disable-user-theming should be true or false" : "A felhasználói témázás letiltásának igaznak vagy hamisnak kell lennie",
    "Saved" : "Mentve",
    "Invalid app given" : "Érvénytelen alkalmazás",
    "Invalid type for setting \"defaultApp\" given" : "A megadott „defaultApp” beállítás típusa érvénytelen",
    "Invalid setting key" : "Érvénytelen konfigurációs kulcs",
    "The file was uploaded" : "A fájl fel lett töltve",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "A feltöltött fájl meghaladja a php.ini upload_max_filesize direktívájában meghatározott méretet.",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "A feltöltött fájl meghaladja a HTML űrlapon megadott MAX_FILE_SIZE direktívájában meghatározott méretet.",
    "The file was only partially uploaded" : "A fájl csak részlegesen lett feltöltve",
    "No file was uploaded" : "Nincs feltöltött fájl",
    "Missing a temporary folder" : "Átmeneti mappa hiányzik",
    "Could not write file to disk" : "A fájlt nem sikerült a lemezre írni",
    "A PHP extension stopped the file upload" : "Egy PHP kiterjesztés megállította a fájl feltöltését",
    "No file uploaded" : "Nincs fájl feltöltve",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Már egyéni témát használ. Lehet, hogy a témázó alkalmazás beállításai felülírták.",
    "Theming" : "Témázás",
    "Appearance and accessibility" : "Megjelenés és akadálymentesítés",
    "PHP Imagick module" : "PHP Imagick modul",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Az „imagick” PHP-modul nem engedélyezett, de a témázó alkalmazás igen. A webhelyikonok előállításához telepítenie és engedélyeznie kell ezt a modult.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Az \"imagick\" PHP modul ebben az esetben nem támogatja az SVG-t. A jobb kompatibilitás érdekében ajánlott telepíteni.",
    "Dark theme with high contrast mode" : "Sötét téma magas kontrasztú móddal",
    "Enable dark high contrast mode" : "Sötét, magas kontrasztú mód engedélyezése",
    "Similar to the high contrast mode, but with dark colours." : "Hasonló a magas kontrasztú módhoz, de sötét színekkel.",
    "Dark theme" : "Sötét téma",
    "Enable dark theme" : "Sötét téma engedélyezése",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Egy szemkímélő sötét téma, amely csökkenti az átlagos fényességet és fényerőt.",
    "System default theme" : "Rendszer alapértelmezett témája",
    "Enable the system default" : "Rendszer alapértelmezésének engedélyezése",
    "Using the default system appearance." : "Az alapértelmezett rendszermegjelenés használata.",
    "Dyslexia font" : "Diszlexia betűkészlet",
    "Enable dyslexia font" : "Diszlexia betűkészlet engedélyezése",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "Az OpenDyslexic egy szabad betűkészlet, amely egyes, diszlexia által okozott, gyakori olvasási hibák csökkentésére lett tervezve.",
    "High contrast mode" : "Magas kontrasztú mód",
    "Enable high contrast mode" : "Magas kontrasztú mód engedélyezése",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "A magas kontrasztú téma megkönnyíti a navigációt. A képi minőség csökken, de az olvashatóság javul.",
    "Light theme" : "Világos téma",
    "Enable the default light theme" : "Alapértelmezett világos téma engedélyezése",
    "The default light appearance." : "Az alapértelmezett világos megjelenés.",
    "Legal notice" : "Jogi nyilatkozat",
    "Privacy policy" : "Adatvédelmi irányelvek",
    "Adjust the Nextcloud theme" : "A Nextcloud téma módosítása",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "A témák lehetővé teszik, hogy könnyedén személyre szabja a példány és a támogatott kliensek megjelenését. Ez minden felhasználó számára látható lesz.",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "A háttérkép helyett sima háttérszínt is beállíthat. Ha háttérképet használ, ez a szín megváltoztatja az alkalmazásmenü ikonjainak színét.",
    "Background color" : "Háttérszín",
    "Upload new logo" : "Új logó feltöltése",
    "Logo" : "Logó",
    "Upload new background and login image" : "Új háttér és bejelentkezőkép feltöltése",
    "Background and login image" : "Háttér és bejelentkezőkép",
    "Advanced options" : "Speciális beállítások",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Telepítse az ImageMagick PHP kiterjesztést SVG képtámogatással, hogy automatikusan előállítsa a kedvencek ikont a feltöltött logó és szín alapján.",
    "Name" : "Név",
    "Web link" : "Webes hivatkozás",
    "a safe home for all your data" : "biztonságos hely az adatai számára",
    "Slogan" : "Szlogen",
    "Primary color" : "Elsődleges szín",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Az elsődleges szín az elemek, például a fontos gombok kiemelésére szolgál. Az aktuális színsémától függően kissé módosulhat.",
    "Legal notice link" : "Jogi nyilatkozat hivatkozása",
    "Privacy policy link" : "Adatvédelmi irányelvek hivatkozása",
    "Header logo" : "Fejléc logó",
    "Upload new header logo" : "Fejléc logó feltöltése",
    "Favicon" : "Kedvencek ikon",
    "Upload new favicon" : "Kedvencek ikon feltöltése",
    "User settings" : "Felhasználói beállítások",
    "Disable user theming" : "Felhasználói témázás letiltása",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Bár kiválaszthatja és testreszabhatja a példányát, a felhasználók módosíthatják a hátterüket és a színeiket. Ha ki akarja kényszeríteni a saját testreszabását, akkor bekapcsolja ezt. ",
    "Appearance and accessibility settings" : "Megjelenési és akadálymentesítési beállítások",
    "Misc accessibility options" : "Egyéb kisegítő lehetőségek",
    "Enable blur background filter (may increase GPU load)" : "Elmosódott háttérszűrő engedélyezése (megnövelheti a GPU terhelést)",
    "Customization has been disabled by your administrator" : "A testreszabást letiltotta a rendszergazda",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "A fontos elemek kiemeléséhez állítson be elsődleges színt. Az olyan elemek színe, mint az elsődleges gombok, kissé eltérhet, ahogyan a kisegítő lehetőségekhez igazodik.",
    "Background and color" : "Háttér és szín",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "A háttér beállítható az alapértelmezett készletből származó képre, egyéni feltöltött képre vagy sima színre.",
    "Keyboard shortcuts" : "Gyorsbillentyűk",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Egyes esetekben a gyorsbillentyűk összeakadhatnak az akadálymentesítési eszközökkel. Hogy helyesen tudjon fókuszálni az eszközre, itt letilthatja a gyorsbillentyűket. Ez az alkalmazásokban is letiltja az összes elérhető gyorsbillentyűt.",
    "Disable all keyboard shortcuts" : "Összes gyorsbillentyű letiltása",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Az akadálymentesítés fontos számunka. A webes szabványokat követjük, és ellenőrizzük, hogy minden használható egér nélkül, illetve akadálymentesítési technológiákkal, például képernyőolvasókkal. Arra törekszünk, hogy a {guidelines}Webes tartalomra vonatkozó akadálymentesítési irányelvek{linkend} 2.1-es változatának AA szinten, a magas kontrasztú témával pedig AAA szinten megfeleljünk.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Ha problémákat tapasztal, jelentse a {issuetracker}hibakövetőnkben{linkend}. És ha segíteni szeretne, csatlakozzon a {designteam}dizájn csapatunkhoz{linkend}!",
    "Current selected app: {app}, position {position} of {total}" : "Jelenleg kiválasztott app: {app}, pozíció: {position}a/az {total}-ból/ből",
    "Move up" : "Mozgatás fel",
    "Move down" : "Mozgatás le",
    "Custom background" : "Egyéni háttér",
    "Plain background" : "Egyszerű háttér",
    "Default background" : "Alapértelmezett háttér",
    "Select a background from your files" : "Válasszon hátteret a fájljai közül",
    "Select background" : "Háttér választása",
    "No background has been selected" : "Nincs kiválasztott háttér",
    "Theme selection is enforced" : "A témaválasztás kényszerített",
    "Navigation bar settings" : "Navigációs sáv beállítás",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Beállíthatja a navigációs sávhoz használt alkalmazások sorrendjét. Az első az alapértelmezett alkalmazás lesz, amely bejelentkezés után vagy a logóra kattintva nyílik meg.",
    "The default app can not be changed because it was configured by the administrator." : "Az alapértelmezett alkalmazást nem lehet megváltoztatni, mert azt a rendszergazda konfigurálta.",
    "The app order was changed, to see it in action you have to reload the page." : "Az alkalmazás sorrend megváltozott, hogy élesben lássa, újra kell töltenie a lapot.",
    "Reset default app order" : "Alapértelmezett alkalmazás sorrend visszaállítása",
    "Could not set the app order" : "Nem sikerült az alkalmazások sorrendjének beállítása",
    "Could not reset the app order" : "Nem sikerült visszaállítani az alkalmazás sorrendet",
    "Reset primary color" : "Elsődleges szín visszaállítása",
    "Could not set primary color" : "Nem sikerült beállítani az elsődleges színt",
    "Default app" : "Alapértelmezett alkalmazás",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Az alapértelmezett alkalmazás az az alkalmazás, amely pl. bejelentkezés után vagy a menüben lévő logóra kattintva nyílik meg.",
    "Use custom default app" : "Egyéni alapértelmezett alkalmazás",
    "Global default app" : "Globális alapértelmezett alkalmazás",
    "Global default apps" : "Globális alapértelmezett alkalmazások",
    "Default app priority" : "Alapértelmezett alkalmazás prioritás",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Ha egy alkalmazás nincs engedélyezve egy felhasználó számára, akkor a következő alacsonyabb prioritású alkalmazás kerül felhasználásra.",
    "Could not set global default apps" : "Nem sikerült a globális alapértelmezett alkalmazások beállítása",
    "Select a custom color" : "Válasszon egyéni színt",
    "Reset to default" : "Visszaállítás alapértelmezettre",
    "Upload" : "Feltöltés",
    "Remove background image" : "Háttérkép eltávolítása",
    "Color" : "Szín",
    "Background" : "Háttér",
    "Set a custom background" : "Egyéni háttér beállítása",
    "Change color" : "Szín módosítása",
    "No background" : "Nincs háttér"
},
"nplurals=2; plural=(n != 1);");
